@@ -1,12 +1,9 @@
 package App::Milter::Limit::PidFile;
-BEGIN {
-  $App::Milter::Limit::PidFile::VERSION = '0.51';
-}
-
+$App::Milter::Limit::PidFile::VERSION = '0.52';
 # ABSTRACT: Milter Limit Pid file class
 
 use strict;
-use File::Pid;
+use Proc::PID::File;
 use App::Milter::Limit::Config;
 use App::Milter::Limit::Log;
 use App::Milter::Limit::Util;
@@ -21,36 +18,26 @@ sub running {
 
     App::Milter::Limit::Util::make_path($$conf{state_dir});
 
-    my $me = File::Pid->program_name;
+    $Pid = Proc::PID::File->new;
 
-    my $pid_file = "$$conf{state_dir}/$me.pid";
+    $Pid->file(dir => $$conf{state_dir});
 
-    $Pid = File::Pid->new({file => $pid_file});
-
-    if ($Pid->running) {
+    if ($Pid->alive) {
         $Pid = undef;
         return 1;
     }
 
-    $Pid->write;
+    $Pid->touch;
 
     # chown the file so we can unlink it
-    chown $$conf{user}, $$conf{group}, $Pid->file;
+    chown $$conf{user}, $$conf{group}, $Pid->{path};
 
     return 0;
 }
 
-# unlink the pid file when we exit.
-END {
-    if (defined $Pid) {
-        debug("removing pid file: ", $Pid->file);
-        $Pid->remove;
-    }
-}
-
 1;
 
-
+__END__
 
 =pod
 
@@ -60,7 +47,7 @@ App::Milter::Limit::PidFile - Milter Limit Pid file class
 
 =head1 VERSION
 
-version 0.51
+version 0.52
 
 =head1 SYNOPSIS
 
@@ -79,9 +66,19 @@ and writes the pid file, and changes its permissions to the user/group
 specified in the milter limit configuration file.  When the program exits, the
 pid file will be removed automatically.
 
+=head1 SOURCE
+
+The development version is on github at L<http://github.com/mschout/milter-limit>
+and may be cloned from L<git://github.com/mschout/milter-limit.git>
+
+=head1 BUGS
+
+Please report any bugs or feature requests to bug-app-milter-limit@rt.cpan.org or through the web interface at:
+ http://rt.cpan.org/Public/Dist/Display.html?Name=App-Milter-Limit
+
 =head1 AUTHOR
 
-  Michael Schout <mschout@cpan.org>
+Michael Schout <mschout@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -90,21 +87,4 @@ This software is copyright (c) 2010 by Michael Schout.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=head1 SOURCE
-
-You can contribute or fork this project via github:
-
-http://github.com/mschout/milter-limit
-
- git clone git://github.com/mschout/milter-limit.git
-
-=head1 BUGS
-
-Please report any bugs or feature requests to bug-app-milter-limit@rt.cpan.org or through the web interface at:
- http://rt.cpan.org/Public/Dist/Display.html?Name=App-Milter-Limit
-
 =cut
-
-
-__END__
-
